PYHPEIMC Python project
=======================

A sample project that exists as an aid for HPE IMC customers to access the RESTFUL API (eAPI) of the Network Management
System Natively from within python.

For example usages, please see the

This project is offered under and Apache2 license and is not supported officialy by HPE.

For more information, please visit the project home page at `GITHub.com <https://github.com/HPENetworking/PYHPEIMC>`_.


What's Changed:

1.0.1 Fixed Readme File
1.0.2 Fixed setup.py to remove unnecessary data directory
1.0.3 Issue with plat.device.set_interface_down function. fixed
1.0.4/5 - Changed library name for HP branding
1.0.6 - Added get_dev_mac_learn function to pyhpeimc.plat.device
1.0.7 - Added run_dev_cmd function to pyhpeimc.plat.device
1.0.8 - Squashed bugs
1.0.9 - Squashed more bugs
1.0.10 - And yet more bugs
1.0.11 - And yet more bugs
1.0.12 - Changed output of pyhpeimc.plat.device.run_dev_cmd to include full response
1.0.13 - Added plat.auth.test_imc_creds function
1.0.14 - Removed Jupyter dependency
1.0.15 - Added icc module under plat. Added various configuration template functions to icc module
1.0.16 - Added version function. Modified create_custom_view to remove unnecessary output.
